@@ -6,3 +6,5 @@ from .xrmb import XRMB
 from .mfeat import MFeat
 from .twitter import Twitter
 from .cub import Cub
+from .mirflickr import MIRFlickr
+from .tgca import TGCA
